{smcl}
{* 2013-08-09 scott long & jeremy freese}{...}
{title:Title}

{p2colset 5 16 23 2}{...}
{p2col:{cmd:mchange} {hline 2}}Marginal effects for regression models | 2013-08-09{p_end}
{p2colreset}{...}


{title:General syntax}

{p 4 18 2}
{cmd:mchange }[{it:varlist}] [{it:if}] [{it:in}]{cmd:,}[{it:mchange-options}] [{it:margins-options}]

{p 6 6 2}
where {it:varlist} is a list of regressors for which changes are to be
computed. If no name is specified, changes for all independent variables
are computed.
{p_end}

{marker overview}
{title:Overview}

{pstd}
{cmd:mchange} uses {cmd:margins} and {cmd:predict} to compute marginal
effects for regression model.
Marginal change is computed as the partial derivative of the outcome
with respect to a regressor.
Discrete changes can be computed for changes of one, a standard deviation,
or specified amount, change from 0 to 1 for binary variables, or changes
over the range or trimmed range.
{p_end}

{pstd}
Average marginal effects (AME) are computed by averaging over the sample.
Changes at specific values of the regressor can also be computed using
{cmd:atmeans} and {cmd:at()} options. These changes include
marginal effects at the mean (MEM) and marginal effects at representative
values (MER).
In Stata versions 11 and 12 computation of average discrete change
can be very slow and standard errors are not available.
This problem is resolved in Stata 13.
{cmd:mchange} works after any regression command supported by {cmd:margins} has
been run.
{p_end}


{title:General syntax}


{title:Options}
{p 8 10 2}

    {help mchange##levels:Specifying values of regressors}
    {help mchange##amount:Selecting the amount of change}
    {help mchange##stats:Selecting statistics to display}
    {help mchange##output:Options controlling output}
    {help mchange##matrices:Saved matrices}
    {help mtable##returns:Returns}

{marker levels}
{dlgtab:Setting values of variables when computing changes}
{pstd}

{pstd}
Predictions are computed using {cmd:margins}. Values at which
changes are computed are controlled with these options:
{p_end}
{p2colset 7 20 21 0}
{synopt:{opt at(atspec)}}
where {help margins##atspec:atspec} is set in the same way as with {cmd:margins}.
For example, at(wc=0 k5=0 age=50).

{synopt:{opt atmeans}}
All regressors not specified with {cmd:at()} are held at their means.
If {cmd:if} or {cmd:in} are used to specify the sample, the means are
computed for the selected observations. If {cmd:atmeans} is not specified,
marginal effects are averaged across observations.

{marker amount}
{dlgtab:Amount of changes}
{pstd}

{pstd}
By default a change from 0 to 1 is computed for a binary regressors.
For continuous variables changes of
one, a statndard deviation, and the marginal change (i.e., partial derivative)
are computed. These defaults can be changed with {cmd:amount()}
and {cmd:amountbinary()}.
{p_end}
{p2colset 7 34 34 0}
{synopt:{opt amount(amount-list)}}Select amount of change to show
for continuous regressors. For example, {cmd:amount(one sd marginal)}.

{synopt:{opt amountb:inary(amount-list)}}
Select types of change to show for binary regressors.

{p2colset 10 22 22 12}{...}
{p2col :Option}Amount of change{p_end}
{p2line}
{p2col :{bf:all}}All types of changes are computed.{p_end}
{p2col :{bf:binary}}Change from 0 to 1.{p_end}
{p2col :{bf:marginal}}Marginal or instantaneous rate of change.{p_end}
{p2col :{bf:one}}Change by 1.{p_end}
{p2col :{bf:range}}Change over range or trimmed range; see {cmd:trim()}.{p_end}
{p2col :{bf:sd}}Change by the regressor's standard deviation or by the
amount specified by {cmd:delta()}. {cmd:amount(delta)} is a synonym for
{cmd:amount(sd)}.{p_end}
{p2line}
{p2colset 7 21 22 0}
{synopt:{opt delta(#)}}
Change by {it:#} units instead of standard deviation
(e.g., delta(4) computes a change of 4).

{synopt:{opt trim(#)}}
Instead of computing change over the range, trim this percentile from
each end of the distribution.

{synopt:{opt uncen:tered}}
For changes of one, a standard deviation, or delta are
compute the change from value of the regressor (e.g., mean to mean+sd).
By default the change would be centered (e.g., mean-sd/2 to mean+sd/2).

{marker stats}
{dlgtab:Statistics}
{pstd}

{pstd}
By default the estimate of change and the p-value for a test that the
change is 0 are displayed. Other statistics can be requested with
the {cmd:statistics()} options.

{p2colset 7 30 10 0}
{synopt:{opt stat:istics(stat-list)}}
specifies which statistics to compute for each change.
{cmd:stats()} is a synonym.

{p2colset 10 20 19 12}{...}
{p2col :Option}Statistic{p_end}
{p2line}
{p2col :{bf:change}}Discrete or marginal change.{p_end}
{p2col :{bf:pvalue}}p-value for test change is 0.{p_end}
{p2col :{bf:se}}Standard error of the estimated change.{p_end}
{p2col :{bf:z}}z-value of test change is 0.{p_end}
{p2col :{bf:ll}}Lower level of CI.{p_end}
{p2col :{bf:ul}}Upper level of CI.{p_end}
{p2col :{bf:start}}Start value for discrete change.{p_end}
{p2col :{bf:end}}End value for discrete change.{p_end}
{p2col :{bf:ci}}Confidence interval along with change.{p_end}
{p2line}
{p2colset 7 24 25 0}
{pstd}
The default level for the confidence interval is 95.
The level can be change with {helpb level:set level}.
{p_end}

{marker output}
{dlgtab:Controlling output}
{pstd}

{pstd}
How output is displayed is controlled by these options.
{p2colset 7 21 22 0}

{synopt:{opt bystat:istic}}
For non-binary models show results with each type of statistics in its
own table (e.g., all the changes in one table; all the p-values in another).
Otherwise, results are organized by variable.

{synopt:{opt dec:imals(#)}}
Number of decimal digits to display.

{synopt:{opt title(title)}}
Label the output with this title.

{synopt:{opt brief}}
Do not show base values, values of r(at) matrix, or
details on how changes were computed.

{synopt:{opt desc:riptive}}
Show table of descriptive statistics.

{synopt:{opt det:ails}}
Display the sometime lengthy output from {cmd:margins} and {cmd:lincom} used
to compute the changes.

{synopt:{opt command:s}}
Display only the commands used with {cmd:margins} without the output.


{marker matrices}
{dlgtab:Returned and saved matrices}
{pstd}

{p 5 5 2}
{ul:Matrices returned as r() returns}
{p_end}

{p2colset 10 24 24 12}{...}
{p2col :{marker matpostfix}Return name}Contents{p_end}
{p2line}
{p2col :{bf:table}}Single matrix with all results organized by variable.{p_end}
{p2col :{bf:change}}Estimates of changes.{p_end}
{p2col :{bf:end}}End value when computing discrete change.{p_end}
{p2col :{bf:ll}}Lower level of CI.{p_end}
{p2col :{bf:pvalue}}p-value for test change is 0.{p_end}
{p2col :{bf:se}}Standard error of the estimated change.{p_end}
{p2col :{bf:start}}Start value when computing discrete change.{p_end}
{p2col :{bf:ul}}Upper level of CI.{p_end}
{p2col :{bf:z}}z-value of test change is 0.{p_end}
{p2line}
{p2colset 7 23 24 0}
{synopt:{opt mat:rix(name)}}
Save r(table) is saved to the matrix {it:name}. If the matrix
    exists, it will be over-written.

{p 5 5 2}
{ul:Matrices saved for {cmd:orplot} and {cmd:dcplot}}
{p_end}

{p2colset 10 33 27 12}{...}
{p2col :Matrices}Contents{p_end}
{p2line}
{p2col :{bf:_mchange_plot_dc}}Discrete and marginal changes.{p_end}
{p2col :{bf:_mchange_plot_pvalue}}p-value for test change is 0.{p_end}
{p2line}
{p2colset 7 24 25 0}
{marker returns}{...}

{dlgtab:Returns}
{p2colset 7 24 25 0}
{p 6 6 2}
{cmd:r(basepred)} is a matrix with the predictions at the baseline values.

{p 6 6 2}
{cmd:r(atmat)} is a matrix containing r(at) from {cmd:margins}.

INCLUDE help spost13_footer
